@@ -71,6 +71,13 @@ class RealPathlibTestCase(fake_filesystem_unittest.TestCase, RealFsTestMixin):
     def use_real_fs(self):
         return False
 
+    def deprecation_warning_since_313(self):
+        return (
+            contextlib.nullcontext()
+            if sys.version_info < (3, 13)
+            else self.assertWarns(DeprecationWarning)
+        )
+
 
 class FakePathlibInitializationTest(RealPathlibTestCase):
     def test_initialization_type(self):
@@ -217,11 +224,7 @@ class FakePathlibPurePathTest(RealPathlibTestCase):
 
     def test_is_reserved_posix(self):
         self.check_posix_only()
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertFalse(self.path("COM1").is_reserved())
@@ -230,11 +233,7 @@ class FakePathlibPurePathTest(RealPathlibTestCase):
     @unittest.skipIf(not is_windows, "Windows specific behavior")
     def test_is_reserved_windows(self):
         self.check_windows_only()
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertTrue(self.path("COM1").is_reserved())
@@ -310,11 +309,7 @@ class FakePathlibPurePosixPathTest(RealPathlibTestCase):
         self.path = self.pathlib.PurePosixPath
 
     def test_is_reserved(self):
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertFalse(self.path("COM1").is_reserved())
@@ -389,11 +384,7 @@ class FakePathlibPureWindowsPathTest(RealPathlibTestCase):
         self.path = self.pathlib.PureWindowsPath
 
     def test_is_reserved(self):
-        with (
-            contextlib.nullcontext()
-            if sys.version_info < (3, 13)
-            else self.assertWarns(DeprecationWarning)
-        ):
+        with self.deprecation_warning_since_313():
             self.assertFalse(self.path("/dev").is_reserved())
             self.assertFalse(self.path("/").is_reserved())
             self.assertTrue(self.path("COM1").is_reserved())
@@ -1385,6 +1376,107 @@ class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
         with self.assertRaises(NotImplementedError):
             self.path(path).group()
 
+    @unittest.skipIf(sys.version_info < (3, 14), "copy() is new in Python 3.14")
+    def test_copy_new_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="test")
+        target = source_path.copy(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertTrue(target.exists())
+        self.assertEqual("test", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "copy() is new in Python 3.14")
+    def test_copy_to_existing_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="foo")
+        self.create_file(target_path, contents="bar")
+        target = source_path.copy(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertTrue(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual("foo", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "copy() is new in Python 3.14")
+    def test_copy_directory(self):
+        source_path = self.path(self.make_path("some_dir"))
+        self.create_file(source_path / "foo", contents="foo")
+        self.create_file(source_path / "bar", contents="bar")
+        self.create_dir(source_path / "dir")
+        target_path = self.make_path("new_dir")
+        target = source_path.copy(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertTrue(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertTrue((target / "foo").exists())
+        self.assertEqual("foo", (target / "foo").read_text())
+        self.assertEqual("bar", (target / "bar").read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "copy_into() is new in Python 3.14")
+    def test_copy_into(self):
+        source_dir = self.path(self.make_path("some_dir"))
+        source_path = source_dir / "foo"
+        self.create_file(source_path, contents="foo")
+        target_path = self.path(self.make_path("new_dir"))
+        self.create_dir(target_path)
+        target = source_path.copy_into(target_path)
+        self.assertTrue(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual(str(target_path / "foo"), str(target))
+        self.assertEqual("foo", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move() is new in Python 3.14")
+    def test_move_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="test")
+        target = source_path.move(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual("test", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move() is new in Python 3.14")
+    def test_move_to_existing_file(self):
+        source_path = self.path(self.make_path("some_file"))
+        target_path = self.make_path("some_other_file")
+        self.create_file(source_path, contents="foo")
+        self.create_file(target_path, contents="bar")
+        target = source_path.move(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual("foo", target.read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move() is new in Python 3.14")
+    def test_move_directory(self):
+        source_path = self.path(self.make_path("some_dir"))
+        self.create_file(source_path / "foo", contents="foo")
+        self.create_file(source_path / "bar", contents="bar")
+        self.create_dir(source_path / "dir")
+        target_path = self.make_path("new_dir")
+        target = source_path.move(target_path)
+        self.assertEqual(target_path, str(target))
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertTrue((target / "foo").exists())
+        self.assertEqual("foo", (target / "foo").read_text())
+        self.assertEqual("bar", (target / "bar").read_text())
+
+    @unittest.skipIf(sys.version_info < (3, 14), "move_into() is new in Python 3.14")
+    def test_move_into(self):
+        source_dir = self.path(self.make_path("some_dir"))
+        source_path = source_dir / "foo"
+        self.create_file(source_path, contents="foo")
+        target_path = self.path(self.make_path("new_dir"))
+        self.create_dir(target_path)
+        target = source_path.move_into(target_path)
+        self.assertFalse(source_path.exists())
+        self.assertTrue(target.exists())
+        self.assertEqual(str(target_path / "foo"), str(target))
+        self.assertEqual("foo", target.read_text())
+
     def test_walk(self):
         """Regression test for #915 - walk results shall be strings."""
         base_dir = self.make_path("foo")
